import {
  Column,
  CreateDateColumn,
  Entity,
  JoinColumn,
  JoinTable,
  ManyToMany,
  ManyToOne,
  PrimaryGeneratedColumn,
} from 'typeorm';
import { UserEntity } from './user.entity';
import { Exclude, Expose } from 'class-transformer';
import { PrivilegeEntity } from './privilege.entity';

@Entity('bans')
@Expose()
export class BanEntity {
  @PrimaryGeneratedColumn()
  id: number;

  @Column({ nullable: false })
  reason: string;

  @Column({ default: false, name: 'privilege_ban' })
  privilegeBan: boolean;

  @Column({ nullable: true })
  ip: string;

  @Column({ nullable: true, default: 32 })
  cidr: number;

  @Column({ type: 'timestamp', name: 'expires_at', nullable: true })
  expiresAt: Date;

  @CreateDateColumn({ name: 'created_at' })
  createdAt: Date;

  @ManyToOne(() => UserEntity, { onDelete: 'CASCADE', nullable: true })
  @JoinColumn({ name: 'user_id' })
  @Exclude()
  user: UserEntity;

  @ManyToOne(() => UserEntity, { onDelete: 'CASCADE' })
  @JoinColumn({ name: 'admin_id' })
  @Exclude()
  admin: UserEntity;

  @ManyToMany(() => PrivilegeEntity, { onDelete: 'CASCADE' })
  @JoinTable({
    name: 'ban_privilege',
    joinColumn: { name: 'ban_id' },
    inverseJoinColumn: { name: 'privilege_id' },
  })
  privileges: PrivilegeEntity[];
}
