import { UserTokenType } from '@freeblox/shared';
import {
  Entity,
  PrimaryGeneratedColumn,
  Column,
  CreateDateColumn,
  ManyToOne,
  JoinColumn,
} from 'typeorm';
import { UserEntity } from './user.entity';

@Entity('user_tokens')
export class UserTokenEntity {
  @PrimaryGeneratedColumn()
  id: number;

  @Column({ nullable: false, type: 'text' })
  token: string;

  @Column({ nullable: true, type: 'text' })
  nonce: string;

  @Column({ type: 'enum', enum: UserTokenType, nullable: false })
  type: UserTokenType;

  @Column({ type: 'timestamp', name: 'expires_at', nullable: true })
  expiresAt: Date;

  @CreateDateColumn({ name: 'created_at' })
  createdAt: Date;

  @ManyToOne(() => UserEntity, { onDelete: 'CASCADE' })
  @JoinColumn({ name: 'user_id' })
  user: UserEntity;

  @ManyToOne(() => UserTokenEntity, { onDelete: 'CASCADE', nullable: true })
  @JoinColumn({ name: 'previous_id' })
  previous: UserTokenEntity;
}
