import { MetaEntity } from '@freeblox/shared';
import { Exclude, Expose } from 'class-transformer';
import { IsOptional, IsString } from 'class-validator';
import {
  Column,
  DeleteDateColumn,
  Entity,
  JoinTable,
  ManyToMany,
  PrimaryGeneratedColumn,
} from 'typeorm';
import { PrivilegeEntity } from './privilege.entity';
import { RoleEntity } from './role.entity';

@Expose()
@Entity('users')
export class UserEntity extends MetaEntity {
  @PrimaryGeneratedColumn('uuid')
  @IsString()
  id: string;

  @Column()
  @IsString()
  username: string;

  @Column()
  @IsString()
  email: string;

  @Column()
  @IsString()
  @IsOptional()
  phone: string;

  @Column({ length: 2 })
  @IsString()
  @IsOptional()
  country: string;

  @Column({ default: 'en', length: 2 })
  @IsString()
  @IsOptional()
  language: string;

  @Column()
  @IsString()
  @Exclude()
  password: string;

  @Column({ nullable: true, name: 'display_name' })
  @IsString()
  @IsOptional()
  displayName: string;

  @Column({ default: false })
  @IsString()
  verified: boolean;

  @Column({ default: true })
  @IsString()
  activated: boolean;

  @Column({ name: 'login_at' })
  @IsString()
  @IsOptional()
  loginAt: Date;

  @ManyToMany(() => PrivilegeEntity)
  @JoinTable({
    name: 'user_privilege',
    joinColumn: {
      name: 'user_id',
    },
    inverseJoinColumn: {
      name: 'privilege_id',
    },
  })
  @Exclude()
  privileges: PrivilegeEntity[];

  @ManyToMany(() => RoleEntity)
  @JoinTable({
    name: 'user_role',
    joinColumn: {
      name: 'user_id',
    },
    inverseJoinColumn: {
      name: 'role_id',
    },
  })
  @Exclude()
  roles: RoleEntity[];

  @DeleteDateColumn({ name: 'deleted_at' })
  @Exclude()
  deletedAt: Date;
}
