import { Knex } from 'knex';

export async function up(knex: Knex): Promise<void> {
  return knex.schema.createTable('bans', (table) => {
    table.increments('id').primary();

    table.text('reason').notNullable();
    table.boolean('privilege_ban').defaultTo(false);

    table.string('ip', 255).nullable();
    table.integer('cidr', 2).nullable().defaultTo(32).unsigned();

    table.uuid('user_id').nullable();
    table.uuid('admin_id').nullable();

    table.timestamp('expires_at').nullable();
    table.timestamp('created_at').notNullable().defaultTo('now()');

    table.foreign('user_id').references('users.id').onDelete('CASCADE');
    table.foreign('admin_id').references('users.id').onDelete('SET NULL');
  });
}

export async function down(knex: Knex): Promise<void> {
  return knex.schema.dropTable('bans');
}
