import { Knex } from 'knex';

export async function up(knex: Knex): Promise<void> {
  return knex.schema.createTable('roles', (table) => {
    table.increments('id').primary();
    table.text('role').notNullable();
    table.string('mpath').nullable().defaultTo('');
    table.integer('parent_id').nullable().unsigned();

    table.uuid('created_by').nullable();
    table.uuid('updated_by').nullable();

    table.timestamps(true, true);

    table.foreign('parent_id').references('roles.id').onDelete('SET NULL');
    table.foreign('created_by').references('users.id').onDelete('SET NULL');
    table.foreign('updated_by').references('users.id').onDelete('SET NULL');
  });
}

export async function down(knex: Knex): Promise<void> {
  return knex.schema.dropTable('roles');
}
