import { Exclude, Expose } from 'class-transformer';
import {
  Column,
  Entity,
  JoinColumn,
  ManyToOne,
  OneToMany,
  PrimaryGeneratedColumn,
  Tree,
  TreeChildren,
  TreeParent,
} from 'typeorm';
import { ContentType } from '../../enums/content-type.enum';

@Entity('content_category')
@Tree('materialized-path')
@Exclude()
export class ContentCategoryEntity {
  @PrimaryGeneratedColumn()
  @Expose()
  id: number;

  @Column()
  @Expose()
  category: string;

  @Column({ name: 'parent_id' })
  parentId: number;

  @TreeParent()
  @JoinColumn({ name: 'parent_id' })
  parent: ContentCategoryEntity;

  @TreeChildren()
  @Expose()
  children: ContentCategoryEntity[];

  @OneToMany(
    () => ContentCategoryContentTypeEntity,
    (entity) => entity.category,
    { eager: true },
  )
  @Expose()
  contentTypes: ContentCategoryContentTypeEntity[];
}

@Entity('content_category_content_type')
@Exclude()
export class ContentCategoryContentTypeEntity {
  @PrimaryGeneratedColumn()
  id: number;

  @Column({ name: 'category_id' })
  categoryId: number;

  @Column({ name: 'content_type', type: String, enum: ContentType })
  @Expose()
  contentType: ContentType;

  @ManyToOne(() => ContentCategoryEntity)
  @JoinColumn({ name: 'category_id' })
  category: ContentCategoryEntity;
}
