import { Exclude, Expose } from 'class-transformer';
import {
  Column,
  Entity,
  Index,
  JoinColumn,
  ManyToOne,
  PrimaryGeneratedColumn,
} from 'typeorm';
import { ContentEntity } from './content.entity';
import { Currency } from '../../enums/currency.enum';
import { UserMetaEntity } from '@freeblox/shared';

@Entity('content_price')
@Expose()
export class ContentPriceEntity extends UserMetaEntity {
  @PrimaryGeneratedColumn()
  id: number;

  @Column({ name: 'content_id' })
  contentId: number;

  @Column()
  @Index()
  price: number;

  @Column({ type: 'enum', enum: Currency })
  @Index()
  currency: Currency;

  @ManyToOne(() => ContentEntity, { onDelete: 'CASCADE' })
  @JoinColumn({ name: 'content_id' })
  @Exclude()
  content: ContentEntity;
}
