import { MetaEntity } from '@freeblox/shared';
import { Exclude, Expose } from 'class-transformer';
import {
  Column,
  CreateDateColumn,
  Entity,
  JoinColumn,
  JoinTable,
  ManyToMany,
  ManyToOne,
  PrimaryGeneratedColumn,
} from 'typeorm';
import { ContentEntity } from './content.entity';
import { ContentRevisionEntity } from './content-revision.entity';
import { IsNumber, IsOptional, IsString } from 'class-validator';
import { ReportStatus } from '../../enums/report-status.enum';
import { ContentModerationEntity } from './content-moderation.entity';

@Entity('content_report')
@Expose()
export class ContentReportEntity extends MetaEntity {
  @PrimaryGeneratedColumn()
  id: number;

  @Column({ name: 'content_id' })
  @IsNumber()
  contentId: number;

  @Column({ name: 'revision_id' })
  revisionId: number;

  @Column({ name: 'user_id', type: 'uuid' })
  @Exclude()
  userId: string;

  @Column({ name: 'moderator_id', type: 'uuid', nullable: true })
  @Exclude()
  moderatorId?: string;

  @Column()
  @IsString()
  reason: string;

  @Column()
  @IsString()
  description: string;

  @Column({ nullable: true })
  @IsString()
  @IsOptional()
  notes?: string;

  @Column({ type: 'enum', enum: ReportStatus })
  status: ReportStatus;

  @CreateDateColumn({ name: 'created_at' })
  @Expose()
  createdAt: Date;

  @CreateDateColumn({ name: 'resolved_at' })
  resolvedAt: Date;

  @ManyToOne(() => ContentEntity, { onDelete: 'CASCADE' })
  @JoinColumn({ name: 'content_id' })
  content: ContentEntity;

  @ManyToOne(() => ContentRevisionEntity, { onDelete: 'CASCADE' })
  @JoinColumn({ name: 'revision_id' })
  revision?: ContentRevisionEntity;

  @ManyToMany(() => ContentModerationEntity)
  @JoinTable({
    name: 'content_report_action',
    joinColumn: {
      name: 'content_report_id',
    },
    inverseJoinColumn: {
      name: 'content_moderation_id',
    },
  })
  actions?: ContentModerationEntity[];
}
