import { UserMetaEntity } from '@freeblox/shared';
import { Exclude, Expose } from 'class-transformer';
import {
  Column,
  CreateDateColumn,
  DeleteDateColumn,
  Entity,
  JoinColumn,
  ManyToOne,
  OneToMany,
  PrimaryGeneratedColumn,
} from 'typeorm';
import { ContentEntity } from './content.entity';
import { ContentAssetEntity } from './content-asset.entity';

@Entity('content_revision')
@Exclude()
export class ContentRevisionEntity extends UserMetaEntity {
  @PrimaryGeneratedColumn()
  @Expose()
  id: number;

  @Column({ name: 'content_id' })
  contentId: number;

  @CreateDateColumn({ name: 'created_at' })
  @Expose()
  createdAt: Date;

  @DeleteDateColumn({ name: 'deleted_at' })
  @Expose()
  deletedAt?: Date;

  @ManyToOne(() => ContentEntity, { onDelete: 'CASCADE' })
  @JoinColumn({ name: 'content_id' })
  content: ContentEntity;

  @OneToMany(() => ContentAssetEntity, (asset) => asset.revision)
  assets: ContentAssetEntity[];
}
