import { Exclude, Expose } from 'class-transformer';
import {
  Column,
  Entity,
  Index,
  JoinTable,
  ManyToMany,
  PrimaryGeneratedColumn,
} from 'typeorm';
import { MetaEntity } from '@freeblox/shared';
import { TradeStatus } from '../../enums/trade-status.enum';
import { ContentOwnershipEntity } from './content-ownership.entity';

@Entity('content_trade')
@Expose()
export class ContentTradeEntity extends MetaEntity {
  @PrimaryGeneratedColumn()
  id: number;

  @Column({ name: 'user_id', type: 'uuid' })
  @Exclude()
  userId: string;

  @Column({ name: 'recipient_id', type: 'uuid' })
  @Exclude()
  recipientId: string;

  @Column({ type: 'enum', enum: TradeStatus })
  @Index()
  status: TradeStatus;

  @Column()
  description: string;

  @ManyToMany(() => ContentOwnershipEntity)
  @JoinTable({
    name: 'content_trade_user_content',
    joinColumn: {
      name: 'content_trade_id',
    },
    inverseJoinColumn: {
      name: 'content_ownership_id',
    },
  })
  userItems: ContentOwnershipEntity[];

  @ManyToMany(() => ContentOwnershipEntity)
  @JoinTable({
    name: 'content_trade_recipient_content',
    joinColumn: {
      name: 'content_trade_id',
    },
    inverseJoinColumn: {
      name: 'content_ownership_id',
    },
  })
  recipientItems: ContentOwnershipEntity[];
}
