import { Exclude, Expose } from 'class-transformer';
import {
  Column,
  Entity,
  Index,
  JoinColumn,
  ManyToOne,
  PrimaryGeneratedColumn,
} from 'typeorm';
import { ContentEntity } from './content.entity';
import { MetaEntity } from '@freeblox/shared';
import { Vote } from '../../enums/vote.enum';

@Entity('content_vote')
@Expose()
export class ContentVoteEntity extends MetaEntity {
  @PrimaryGeneratedColumn()
  id: number;

  @Column({ name: 'content_id' })
  @Exclude()
  contentId: number;

  @Column({ name: 'user_id', type: 'uuid', nullable: true })
  @Index()
  @Exclude()
  userId: string;

  @Column({ type: 'enum', enum: Vote })
  vote: Vote;

  @ManyToOne(() => ContentEntity, { onDelete: 'CASCADE' })
  @JoinColumn({ name: 'content_id' })
  @Exclude()
  content: ContentEntity;
}
