import { Knex } from 'knex';

export async function up(knex: Knex): Promise<void> {
  await Promise.all([
    knex.schema.createTable('content_moderation', (table) => {
      table.increments('id').primary();

      table.integer('content_id').unsigned().notNullable();
      table.integer('revision_id').unsigned().notNullable();

      table.uuid('user_id').nullable();

      table
        .enum('action', ['pending', 'approve', 'reject', 'forward'])
        .index()
        .notNullable()
        .defaultTo('pending');

      table
        .enum('rejection_reason', ['tos', 'illegal', 'dmca', 'other'])
        .index()
        .nullable();

      table.text('description').nullable();

      table.boolean('penalty').notNullable().defaultTo(false);
      table.boolean('asset_delete').notNullable().defaultTo(false);

      table.timestamps(true, true);
      table.timestamp('decided_at');

      table.foreign('content_id').references('content.id').onDelete('CASCADE');
      table
        .foreign('revision_id')
        .references('content_revision.id')
        .onDelete('CASCADE');
    }),
    knex.schema.createTable('content_moderation_ban', (table) => {
      table.increments('id').primary();
      table.integer('content_moderation_id').unsigned().notNullable();
      table.integer('ban_id').unsigned().nullable();
      table
        .foreign('content_moderation_id')
        .references('content_moderation.id')
        .onDelete('CASCADE');
    }),
  ]);
}

export async function down(knex: Knex): Promise<void> {
  await Promise.all([
    knex.schema.dropTable('content_moderation'),
    knex.schema.dropTable('content_moderation_ban'),
  ]);
}
