import { Knex } from 'knex';

export async function up(knex: Knex): Promise<void> {
  return knex.schema.createTable('content_price', (table) => {
    table.increments('id').primary();

    table.integer('content_id').unsigned().notNullable();

    table.integer('price').unsigned().notNullable().defaultTo(0).index();
    table.enum('currency', ['whole', 'denom']).notNullable().index();

    table.uuid('created_by').nullable();
    table.uuid('updated_by').nullable();

    table.timestamps(true, true);

    table.foreign('content_id').references('content.id').onDelete('CASCADE');
  });
}

export async function down(knex: Knex): Promise<void> {
  return knex.schema.dropTable('content_price');
}
