import { Knex } from 'knex';

export async function up(knex: Knex): Promise<void> {
  return knex.schema.createTable('content_ownership', (table) => {
    table.increments('id').primary();

    table.integer('content_id').unsigned().notNullable();
    table.uuid('user_id').notNullable();

    table
      .enum('source', ['author', 'purchase', 'trade', 'gift'])
      .notNullable()
      .defaultTo('author')
      .index();

    table.integer('previous_ownership_id').unsigned().nullable();

    table.integer('purchase_price').nullable();
    table.enum('purchase_currency', ['whole', 'denom']).nullable();

    table.integer('serial').unsigned().nullable();

    table.uuid('created_by').nullable();
    table.uuid('updated_by').nullable();

    table.timestamps(true, true);
    table.timestamp('ended_at').nullable();
    table.timestamp('expires_at').nullable();

    table.foreign('content_id').references('content.id').onDelete('CASCADE');
    table
      .foreign('previous_ownership_id')
      .references('content_ownership.id')
      .onDelete('CASCADE');
  });
}

export async function down(knex: Knex): Promise<void> {
  return knex.schema.dropTable('content_ownership');
}
