import { Knex } from 'knex';

export async function up(knex: Knex): Promise<void> {
  await Promise.all([
    knex.schema.createTable('content_trade', (table) => {
      table.increments('id').primary();

      table.uuid('user_id').notNullable();
      table.uuid('recipient_id').notNullable();

      table
        .enum('status', [
          'sent',
          'opened',
          'rejected',
          'return_to_sender',
          'confirmed',
          'cancelled',
        ])
        .notNullable()
        .defaultTo('sent')
        .index();

      table.text('description').nullable();

      table.timestamps(true, true);
    }),
    knex.schema.createTable('content_trade_user_content', (table) => {
      table.integer('content_trade_id').unsigned().notNullable();
      table.integer('content_ownership_id').unsigned().notNullable();
      table
        .foreign('content_trade_id')
        .references('content_trade.id')
        .onDelete('CASCADE');
      table
        .foreign('content_ownership_id')
        .references('content_ownership.id')
        .onDelete('CASCADE');
    }),
    knex.schema.createTable('content_trade_recipient_content', (table) => {
      table.integer('content_trade_id').unsigned().notNullable();
      table.integer('content_ownership_id').unsigned().notNullable();
      table
        .foreign('content_trade_id')
        .references('content_trade.id')
        .onDelete('CASCADE');
      table
        .foreign('content_ownership_id')
        .references('content_ownership.id')
        .onDelete('CASCADE');
    }),
  ]);
}

export async function down(knex: Knex): Promise<void> {
  await Promise.all([
    knex.schema.dropTable('content_trade'),
    knex.schema.dropTable('content_trade_user_content'),
    knex.schema.dropTable('content_trade_recipient_content'),
  ]);
}
