import { Knex } from 'knex';

export async function up(knex: Knex): Promise<void> {
  await Promise.all([
    knex.schema.createTable('content_report', (table) => {
      table.increments('id').primary();

      table.integer('content_id').index().unsigned().notNullable();
      table.uuid('user_id').notNullable();
      table.uuid('moderator_id').nullable();

      table.text('reason').notNullable();
      table.text('description').notNullable();
      table.text('notes').nullable();

      table
        .enum('status', ['open', 'closed', 'invalid', 'resolved'])
        .index()
        .notNullable()
        .defaultTo('open');

      table.timestamps(true, true);
      table.timestamp('resolved_at');

      table.foreign('content_id').references('content.id').onDelete('CASCADE');
    }),
    knex.schema.createTable('content_report_action', (table) => {
      table.integer('content_report_id').index().unsigned().notNullable();
      table.integer('content_moderation_id').index().unsigned().notNullable();
      table
        .foreign('content_report_id')
        .references('content_report.id')
        .onDelete('CASCADE');
      table
        .foreign('content_moderation_id')
        .references('content_moderation.id')
        .onDelete('CASCADE');
    }),
  ]);
}

export async function down(knex: Knex): Promise<void> {
  await Promise.all([
    knex.schema.dropTable('content_report'),
    knex.schema.dropTable('content_report_action'),
  ]);
}
