import { Knex } from 'knex';

export async function up(knex: Knex): Promise<void> {
  await Promise.all([
    knex.schema.createTable('content_category', (table) => {
      table.increments('id').primary();
      table.text('category').notNullable();
      table.string('mpath').nullable().defaultTo('');
      table.integer('parent_id').nullable().unsigned();
      table
        .foreign('parent_id')
        .references('content_category.id')
        .onDelete('SET NULL');
    }),
    knex.schema.createTable('content_category_content_type', (table) => {
      table.increments('id').primary();
      table.integer('category_id').nullable().unsigned();
      table.string('content_type').notNullable();
      table
        .foreign('category_id')
        .references('content_category.id')
        .onDelete('SET NULL');
    }),
  ]);
}

export async function down(knex: Knex): Promise<void> {
  Promise.all([
    knex.schema.dropTable('content_category'),
    knex.schema.dropTable('content_category_content_type'),
  ]);
}
