import { Knex } from 'knex';
import { ContentType } from '../../enums/content-type.enum';

const categories = [
  {
    name: 'characters',
    parent: null,
    contentTypes: [ContentType.CHARACTER],
    id: 0,
    path: '',
  },
  {
    name: 'clothing',
    parent: null,
    contentTypes: [ContentType.TSHIRT, ContentType.SHIRT, ContentType.PANTS],
    id: 0,
    path: '',
  },
  {
    name: 'tshirts',
    parent: 'clothing',
    contentTypes: [ContentType.TSHIRT],
    id: 0,
    path: '',
  },
  {
    name: 'shirts',
    parent: 'clothing',
    contentTypes: [ContentType.SHIRT],
    id: 0,
    path: '',
  },
  {
    name: 'pants',
    parent: 'clothing',
    contentTypes: [ContentType.PANTS],
    id: 0,
    path: '',
  },
  {
    name: 'accessories',
    parent: null,
    contentTypes: [
      ContentType.ACCESSORY,
      ContentType.HAT,
      ContentType.FACE,
      ContentType.FRONT,
      ContentType.BODY,
      ContentType.BACK,
      ContentType.TOOL,
    ],
    id: 0,
    path: '',
  },
  {
    name: 'hats',
    parent: 'accessories',
    contentTypes: [ContentType.HAT],
    id: 0,
    path: '',
  },
  {
    name: 'faces',
    parent: 'accessories',
    contentTypes: [ContentType.FACE],
    id: 0,
    path: '',
  },
  {
    name: 'front',
    parent: 'accessories',
    contentTypes: [ContentType.FRONT],
    id: 0,
    path: '',
  },
  {
    name: 'body',
    parent: 'accessories',
    contentTypes: [ContentType.BODY],
    id: 0,
    path: '',
  },
  {
    name: 'back',
    parent: 'accessories',
    contentTypes: [ContentType.BACK],
    id: 0,
    path: '',
  },
  {
    name: 'tools',
    parent: 'accessories',
    contentTypes: [ContentType.TOOL],
    id: 0,
    path: '',
  },
  {
    name: 'creator',
    parent: null,
    contentTypes: [
      ContentType.MESH,
      ContentType.TEXTURE,
      ContentType.GAMEOBJECT,
      ContentType.SOUND,
      ContentType.ANIMATION,
    ],
    id: 0,
    path: '',
  },
  {
    name: 'meshes',
    parent: 'creator',
    contentTypes: [ContentType.MESH],
    id: 0,
    path: '',
  },
  {
    name: 'textures',
    parent: 'creator',
    contentTypes: [ContentType.TEXTURE],
    id: 0,
    path: '',
  },
  {
    name: 'gameobjects',
    parent: 'creator',
    contentTypes: [ContentType.GAMEOBJECT],
    id: 0,
    path: '',
  },
  {
    name: 'sounds',
    parent: 'creator',
    contentTypes: [ContentType.SOUND],
    id: 0,
    path: '',
  },
  {
    name: 'animation',
    parent: 'creator',
    contentTypes: [ContentType.ANIMATION],
    id: 0,
    path: '',
  },
];

export async function seed(knex: Knex): Promise<void> {
  for (const type of categories) {
    const existing = await knex('content_category').where({
      category: type.name,
    });

    let parentId: number;
    let parentPath = '';

    if (type.parent) {
      const parentItem = categories.find((entry) => entry.name === type.parent);
      if (parentItem?.id) {
        parentId = parentItem.id;
        parentPath = parentItem.path;
      }
    }

    if (existing?.length) {
      type.id = existing[0].id;
      type.path = parentPath
        ? parentPath + '.' + existing[0].id
        : existing[0].id.toString();
    } else {
      const [newItem] = await knex('content_category')
        .insert({
          category: type.name,
          parent_id: parentId,
        })
        .returning(['id']);

      type.id = newItem.id;
      type.path = parentPath
        ? parentPath + '.' + newItem.id
        : newItem.id.toString();

      await knex('content_category')
        .where({ id: newItem.id })
        .update({ mpath: type.path });
    }

    for (const contentType of type.contentTypes) {
      const existing = await knex('content_category_content_type').where({
        content_type: contentType,
        category_id: type.id,
      });
      if (existing?.length) continue;

      await knex('content_category_content_type').insert({
        content_type: contentType,
        category_id: type.id,
      });
    }
  }
}
