import { ApiProperty } from '@nestjs/swagger';
import { ContentType } from 'apps/catalog/src/enums/content-type.enum';
import { Currency } from 'apps/catalog/src/enums/currency.enum';
import { Privacy } from 'apps/catalog/src/enums/privacy.enum';
import {
  ContentAssetTypeProperties,
  CreateContentFiles,
  CreateContentPricing,
  CreateContentRequest,
} from 'apps/catalog/src/interfaces/create-content-request.interface';
import { Type } from 'class-transformer';

export class CreateContentFilesDto implements CreateContentFiles {
  [x: string]: ContentAssetTypeProperties;
}

export class CreateContentPricingDto implements CreateContentPricing {
  @ApiProperty({ type: String, enum: Currency })
  currency: Currency;

  @ApiProperty()
  price: number;
}

export class CreateContentDto implements CreateContentRequest {
  @ApiProperty()
  name: string;

  @ApiProperty()
  description: string;

  @ApiProperty({ enum: Privacy })
  privacy: Privacy;

  @ApiProperty({ enum: ContentType })
  type: ContentType;

  @ApiProperty({ nullable: true })
  parentId?: number;

  @ApiProperty({ nullable: true })
  onsale?: boolean;

  @ApiProperty({ nullable: true })
  commentsEnabled?: boolean;

  @ApiProperty({ nullable: true })
  openSource?: boolean;

  @ApiProperty({ nullable: true })
  stock?: number;

  @ApiProperty({ nullable: true })
  license?: string;

  @ApiProperty({ nullable: true, type: CreateContentFilesDto })
  @Type(() => CreateContentFilesDto)
  files?: CreateContentFilesDto;

  @ApiProperty({ nullable: true, type: CreateContentPricingDto, isArray: true })
  @Type(() => CreateContentPricingDto)
  prices?: CreateContentPricingDto[];
}
