import { Module } from '@nestjs/common';
import { ServerController } from './server.controller';
import { ServerService } from './server.service';
import { makeKnex, makeTypeOrm, natsClient } from '@freeblox/shared';
import { ClientsModule } from '@nestjs/microservices';
import { ConfigModule, ConfigService } from '@nestjs/config';
import { TypeOrmModule } from '@nestjs/typeorm';

@Module({
  imports: [
    ConfigModule.forRoot({
      ignoreEnvFile: process.env.NODE_ENV === 'development',
      load: [makeKnex('server', __dirname), makeTypeOrm('server')],
    }),
    TypeOrmModule.forRootAsync({
      imports: [ConfigModule],
      inject: [ConfigService],
      useFactory: (config: ConfigService) => config.get('typeorm'),
    }),
    ClientsModule.register([
      natsClient('server'),
      natsClient('auth'),
      natsClient('game'),
      natsClient('player'),
    ]),
  ],
  controllers: [ServerController],
  providers: [ServerService],
})
export class ServerModule {}
