import { HttpStatus } from '@nestjs/common';

export class HttpRpcException {
  public name = 'HttpRpcException';
  isRpcException = true;

  constructor(
    public readonly error: string | object,
    public status: HttpStatus,
    public stack?: string,
  ) {
    Error.captureStackTrace(this, HttpRpcException);
  }

  getStatus() {
    return this.status;
  }

  getError() {
    return this.error;
  }

  get message() {
    return this.error.toString();
  }
}

export class BadRequestRpcException extends HttpRpcException {
  public name = 'BadRequestRpcException';
  constructor(message: string | object) {
    super(message, HttpStatus.BAD_REQUEST);
  }
}

export class NotFoundRpcException extends HttpRpcException {
  public name = 'NotFoundRpcException';
  constructor(message: string | object) {
    super(message, HttpStatus.NOT_FOUND);
  }
}

export class ForbiddenRpcException extends HttpRpcException {
  public name = 'ForbiddenRpcException';
  constructor(message: string | object) {
    super(message, HttpStatus.FORBIDDEN);
  }
}

export class UnauthorizedRpcException extends HttpRpcException {
  public name = 'UnauthorizedRpcException';
  constructor(message: string | object) {
    super(message, HttpStatus.UNAUTHORIZED);
  }
}

export class PreconditionFailedRpcException extends HttpRpcException {
  public name = 'PreconditionFailedRpcException';
  constructor(message: string | object) {
    super(message, HttpStatus.PRECONDITION_FAILED);
  }
}

export class ValidationRpcException extends BadRequestRpcException {
  public name = 'ValidationRpcException';
  constructor(message: string | object = 'Validation failed') {
    super(message);
  }
}
